#define MAIN 1

#include "system_defines.h"
#include "Cyclone_Device.h"
#include "pmbus_commands.h"
#include "pmbus_common.h"
#include "pmbus_topology.h"
#include "variables.h"
#include "functions.h"
#include "software_interrupts.h"
#include "cyclone_defines.h"
#include "stdio.h"

#define PCLK_PERIOD		4.0e-9
#define PERIOD_SECONDS	10.0e-6
#define PERIOD			((int)(PERIOD_SECONDS/PCLK_PERIOD)<<4)
#define EVENT1			(int)(PERIOD*0.2)

Uint32 FAULTMUXINTSTAT_value;
float temp= 0.2;

void init_dpwm0(void)
{
    Dpwm0Regs.DPWMCTRL0.bit.PWM_EN = 0;     // disable DPWM0 locally during initilization

	Dpwm0Regs.DPWMCTRL0.bit.CLA_EN = 0;		// default is 1 (i.e. default is to use the filter output to control DPWM)

	Dpwm0Regs.DPWMPRD.all = PERIOD;         // use .all for all values, so that the scaling matches
	Dpwm0Regs.DPWMEV1.all = EVENT1;         // set EVENT 1 to 0% (start) of period

    Dpwm0Regs.DPWMINT.bit.PRD_INT_EN = 1;   //open DPWM0 interrupt
	Dpwm0Regs.DPWMINT.bit.PRD_INT_SCALE = 0010; //Period Interrupt generated once every 4 switching cycles
//	CimRegs.FIRQPR.bit.FIRQ_DPWM0 = 1;  // set to FIQ mode

    Dpwm0Regs.DPWMCTRL0.bit.PWM_EN = 1;     // enable DPWM0 locally
	LoopMuxRegs.GLBEN.bit.DPWM0_EN = 1;     // enable DPWM0 globally
}


void main()
{

	if(GioRegs.FAULTIN.bit.FLT3_IN == 0)
	{
		clear_integrity_word();
	}

	init_pmbus(0x58);						// initialize PMBus handler


	//ʼжϳ
	    //Disable interrupts
	    disable_interrupt();
	    disable_fast_interrupt();
	    //This is necessary to make sure all interrupt status values are
	    //cleared. Added here by ZCS feature
	    FAULTMUXINTSTAT_value = FaultMuxRegs.FAULTMUXINTSTAT.all;
	    //Configure IRQ
	    write_reqmask(CIMINT_ALL_DPWM0 | CIMINT_ALL_FAULT_MUX);
	    //Configure FIQ
	    write_firqpr(CIMINT_ALL_DPWM0 | CIMINT_ALL_FAULT_MUX);
//	    Enable interrupts
	    enable_fast_interrupt();
	    enable_interrupt();

	init_dpwm0();							// initialize DPWM0

    //This is necessary to make sure all interrupt status values are
    //cleared.
    FAULTMUXINTSTAT_value = FaultMuxRegs.FAULTMUXINTSTAT.all;

	for(;;)
	{
		pmbus_handler();
	}
}


//#pragma INTERRUPT(c_int00,RESET)
void c_int00(void)
{
	main();
}

#pragma INTERRUPT(ADCValueGet,IRQ)
void ADCValueGet(void)
{

    temp=temp+0.01;
    if(temp>0.9)
    {
        temp=0.2;
    }

    Dpwm0Regs.DPWMEV1.all = temp*PERIOD;

//    Dpwm0Regs.DPWMINT.bit.PRD = 0;   //clear the flag
    Uint32 read_scrap;
    read_scrap = Dpwm3Regs.DPWMINT.bit.PRD;
}
